@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package System::Sub;
-$System::Sub::VERSION = '0.150960';
+$System::Sub::VERSION = '0.162800';
 use File::Which ();
 use Sub::Name 'subname';
 use Symbol 'gensym';
@@ -173,14 +173,15 @@ sub _build_sub
         if (wantarray) {
             my @output;
             if ($output_cb) {
+                local $_;
                 while (<$out>) {
                     chomp;
                     push @output, $output_cb->($_)
                 }
             } else {
-                while (<$out>) {
-                    chomp;
-                    push @output, $_
+                while (my $x = <$out>) {
+                    chomp $x;
+                    push @output, $x
                 }
             }
             close $out;
@@ -198,6 +199,7 @@ sub _build_sub
             return $output
         } else { # void context
             if ($output_cb) {
+                local $_;
                 while (<$out>) {
                     chomp;
                     $output_cb->($_)
@@ -223,7 +225,7 @@ System::Sub - Wrap external command with a DWIM sub
 
 =head1 VERSION
 
-version 0.150960
+version 0.162800
 
 =head1 SYNOPSIS
 
